@@ -146,6 +146,8 @@ private:
         bool reload(ScriptCompiler *img);
 	void down(void);
 
+    Name *getIncoming(ScriptImage *img, BayonneSession *s, Event *event);
+
 	static bool testKey(ScriptInterp *interp, const char *v);
 
 public:
@@ -192,13 +194,12 @@ class Checks : public ScriptChecks, public Bayonne
 {
 public:
         const char *chkCDR(Line *line, ScriptImage *img); 
-        const char *chkRegister(Line *line, ScriptImage *img);
-        const char *chkAssign(Line *line, ScriptImage *img);
-        const char *chkSelect(Line *line, ScriptImage *img);   
+        const char *chkKeydata(Line *line, ScriptImage *img);
         const char *chkKey(Line *line, ScriptImage *img);  
 	const char *chkEndinput(Line *line, ScriptImage *img);
 	const char *chkParse(Line *line, ScriptImage *img);
 	const char *chkStart(Line *line, ScriptImage *img);
+	const char *chkSelect(Line *line, ScriptImage *img);
 };
 
 class Methods : public BayonneSession
@@ -210,6 +211,7 @@ public:
 	bool scrEndinput(void);
 	bool scrParse(void);
 	bool scrStart(void);
+	bool scrKeydata(void);
 
 	bool xmlAssign(void);
 	bool xmlDebug(void);
