@@ -20,6 +20,132 @@ namespace binder {
 using namespace ost;
 using namespace std;
 
+class Image : public ScriptImage
+{
+private:
+    Image() : ScriptImage(NULL, NULL) {};
+
+public:
+    inline void *alloc(size_t size)
+		{return ScriptImage::alloc(size);};
+};
+
+const char *Checks::chkJoin(Line *line, ScriptImage *img)
+{
+	if(line->argc)
+		return "join uses no keywords or arguments";
+
+	return NULL;
+}
+
+const char *Checks::chkRedial(Line *line, ScriptImage *img)
+{
+	if(line->argc > 1)
+		return "redial may have optional variable only";
+
+	return NULL;
+}
+
+const char *Checks::chkRecall(Line *line, ScriptImage *img)
+{
+	if(line->argc)
+		return "recall uses no keywords or arguments";
+
+	return NULL;
+}
+
+
+const char *Checks::chkFeature(Line *line, ScriptImage *img)
+{
+        if(!useKeywords(line, "=encoding=framing"))
+                return "invalid keyword used for reconnect";
+
+        return NULL;
+}
+
+const char *Checks::chkRing(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+
+	if(!useKeywords(line, "=coverage=delay=timeout=duration=tone=encoding=framing"))
+		return "invalud keyword used for ring";
+
+	if(!getOption(line, &idx))
+		return "select at least one ring group script to use";
+
+	return NULL;
+}
+
+const char *Checks::chkConnect(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+	
+	if(!useKeywords(line, "=session=caller=display=timeout=duration=tone=encoding=framing"))
+		return "invalid keyword used for connect";
+
+	if(!getOption(line, &idx))
+		return "missing dial option";
+
+	if(!getOption(line, &idx))
+		return NULL;
+
+	if(getOption(line, &idx))
+		return "too many arguments for connect";
+
+	return NULL;
+}
+
+const char *Checks::chkStart(Line *line, ScriptImage *img)
+{
+        unsigned idx = 0;
+	const char *cp;
+
+        if(!useKeywords(line, "=session=caller=display"))
+                return "invalid keyword used for start";
+
+        if(!getOption(line, &idx))
+                return "no dial command specified";
+
+        if(!getOption(line, &idx))
+                return "no script specified";
+
+	while(NULL != (cp = getOption(line, &idx)))
+	{
+		if(*cp != '&' && *cp != '%')
+			return "remaining arguments must be variables";
+	}
+
+        return NULL;
+}
+
+const char *Checks::chkStop(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "stop has no members";
+
+	if(hasKeywords(line))
+		return "stop uses no keywords";
+
+	if(line->argc < 1)
+		return "stop missing session id argument";
+
+	if(line->argc > 1)
+		return "stop only has one argument";
+
+	return NULL;
+}
+
+const char *Checks::chkEndinput(Line *line, ScriptImage *img)
+{
+        if(getMember(line))
+                return "endinput has no members";
+
+        if(line->argc > 0)
+                return "endinput has no arguments";
+
+        return NULL; 
+}  
+
 const char *Checks::chkDial(Line *line, ScriptImage *img)       
 {
         unsigned idx = 0;
@@ -36,51 +162,6 @@ const char *Checks::chkDial(Line *line, ScriptImage *img)
         return NULL;
 } 
 
-const char *Checks::chkWait(Line *line, ScriptImage *img)
-{
-        unsigned idx = 0;
-
-        if(getMember(line))
-                return "wait no members used";
-
-        if(!useKeywords(line, "=timeout=id"))
-                return "invalid keyword for wait";
-
-        return NULL;
-}  
-
-const char *Checks::chkJoin(Line *line, ScriptImage *img)    
-{
-        unsigned idx = 0;  
-
-        if(getMember(line))
-                return "join no members used";   
-
-        if(!useKeywords(line, "=timeout"))      
-                return "invalid keyword for join";
-
-        if(!getOption(line, &idx))
-                return "no join session id requested";
-
-        return NULL;
-}
-
-const char *Checks::chkCancel(Line *line, ScriptImage *img)
-{
-        unsigned idx = 0;
-
-        if(getMember(line))
-                return "cancel has no members";
-
-        if(hasKeywords(line))
-                return "cancel has no keywords";
-
-        if(!getOption(line, &idx))
-                return "cancel requires at least one timeslot argument";
-
-        return NULL;
-} 
-
 const char *Checks::chkCDR(Line *line, ScriptImage *img)
 {
 	char var[65];
@@ -118,23 +199,93 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	const char *cp = getMember(line);
 	Name *scr = img->getCurrent();
 	BayonneDriver *driver;
+	const char *ext = strrchr(scr->filename, '.');
+	char dbuf[15];
+	char *sp;
 
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot register non-public script";
 
-	if(cp)
-		++cp;
+	if(scr->first && !stricmp(scr->first->cmd, "_keydata_"))
+		return "cannot add additional registration to this entry";
 
-	driver = BayonneDriver::get(cp);
+	if(ext && !stricmp(ext, ".conf"))
+	{
+		if(cp)
+			return "cannot register to alternate in config";
+
+		cp = strrchr(scr->filename, '/');
+		if(cp)
+			++cp;
+		else
+			cp = scr->filename;
+
+		setString(dbuf, sizeof(dbuf), cp);
+		sp = strchr(dbuf, '.');
+		if(sp)
+			*sp = 0;
+		cp = dbuf;
+	}
+
+	if(cp)
+		driver = BayonneDriver::get(cp);
+	else
+		driver = BayonneDriver::getProtocol();
 		
 	if(!driver)
 	{
-		slog.warn("cannot register %s with %s", scr->name, cp);
+		slog.warn("cannot register %s", scr->name);
 		return "";
 	}
 	return driver->registerScript(img, line);
 }
-	
+
+const char *Checks::chkKeydata(Line *line, ScriptImage *ip)
+{
+	Image *img = (Image *)ip;
+	Name *scr = img->getCurrent();
+	BayonneDriver *driver;
+	const char *cp;
+	char dbuf[15];
+	char *sp;
+
+	if(scr->access != ScriptInterp::scrPUBLIC)
+		return "cannot register non-public script";
+
+	cp = strrchr(scr->filename, '/');
+	if(cp)
+		++cp;
+	else
+		cp = scr->filename;
+
+	setString(dbuf, sizeof(dbuf), cp);
+	sp = strchr(dbuf, '.');
+	if(sp)
+		*sp = 0;
+	driver = BayonneDriver::get(dbuf);
+
+	if(!driver)
+	{
+		slog.warn("cannot register keydata %s with driver", scr->name);
+		return "";
+	}
+
+	cp = findKeyword(img, line, "type");
+	if(cp && !strnicmp(cp, "ext", 3))
+		return "extensions not supported for xml app server binding";
+
+	if(cp && !stricmp(cp, "agent"))		
+		return "acd agents not support for xml app server binding";
+
+	line->scr.method = (Method)&Methods::scrKeydata;
+	line = (Line *)memcpy(img->alloc(sizeof(Line)), line, sizeof(Line));
+
+	cp = driver->registerScript(ip, line);
+	if(cp && *cp)
+		return cp;
+	return NULL;
+}
+
 const char *Checks::chkAssign(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
@@ -143,6 +294,13 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	char tag[65];
 	BayonneDriver *driver;
 	BayonneSession *s;
+	const char *ext = strrchr(scr->filename, '.');
+
+	if(scr->first && !stricmp(scr->first->cmd, "_keydata_"))
+		return "cannot add assignment to this entry";
+
+	if(ext && !stricmp(ext, ".conf"))
+		return "assign not used in config";
 
 	if(hasKeywords(line))
 		return "keywords not used for assign";
@@ -168,9 +326,6 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	if(!strnicmp(line->cmd, "incoming.", 9))
 		return "invalid member for incoming"; 
 
-	if(cp && *cp == '.')
-		++cp;
-
 	if(cp)
 	{
 		if(!stricmp(cp, "timeslot"))
@@ -257,12 +412,23 @@ dnis:
 
 const char *Checks::chkSelect(Line *line, ScriptImage *img)
 {
-	const char *cp = getMember(line);
+	const char *cp = getMember(line), *sn = "";
 	Name *scr = img->getCurrent();
 	timeslot_t ts;
 	unsigned idx = 0, spid;
 	interface_t iface;
+	BayonneDriver *driver;
 	BayonneSession *session;
+	char *sp;
+	const char *ext = strrchr(scr->filename, '.');
+	const char *fn = strrchr(scr->filename, '/');
+	char buf[65];
+	char sbuf[96];
+
+	if(fn)
+		++fn;
+	else
+		fn = scr->filename;
 
 	if(hasKeywords(line))
 		return "keywords not used for select";
@@ -272,9 +438,47 @@ const char *Checks::chkSelect(Line *line, ScriptImage *img)
 
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot select from non-public script";	
+	
+	snprintf(sbuf, sizeof(sbuf), "select.%s", scr->name);
 
-	if(cp && *cp == '.')
-		++cp;
+	if(!stricmp(ext, ".conf"))
+	{
+		setString(buf, sizeof(buf), fn);
+		sp = strchr(buf, '.');		
+		if(sp)
+			*sp = 0;
+		driver = BayonneDriver::get(buf);
+drivermode:
+		sn = strrchr(scr->name, ':');
+		if(sn)
+			++sn;
+		else
+			sn = scr->name;
+
+		if(!driver && stricmp(buf, "trunk"))
+			return "cannot select in this config";
+
+		if(!driver)
+		{
+			snprintf(sbuf, sizeof(sbuf), "select.%s", sn);
+			goto trunking;
+		}
+
+		cp = getOption(line, &idx);
+		if(!cp)
+			return "default server missing from select";
+
+		if(strchr(cp, '@'))
+			return "default server cannot include user";
+
+		snprintf(sbuf, sizeof(sbuf), "start-%s.%s", buf, sn);
+		img->setPointer(sbuf, scr);
+		img->addSelect(line);
+		return "";
+	}
+
+trunking:
+	img->setPointer(sbuf, scr);
 
 	if(cp)
 	{
@@ -284,6 +488,13 @@ const char *Checks::chkSelect(Line *line, ScriptImage *img)
 		if(!stricmp(cp, "span"))
 			goto span;
 
+		driver = BayonneDriver::get(cp);
+		if(driver)
+		{
+			setString(buf, sizeof(buf), cp);
+			goto drivermode;
+		}
+
 		return "unknown form of select";
 	}
 
@@ -342,37 +553,4 @@ const char *Checks::chkKey(Line *line, ScriptImage *img)
         return chkAllVars(line, img);
 }  
 
-
-const char *Checks::chkConnect(Line *line, ScriptImage *img)
-{
-        unsigned idx = 0;
-
-        if(!useKeywords(line, "=caller=display=vars=session=timeout=tone=duration"))
-                return "invalid keyword used for dial";
-
-        if(!getOption(line, &idx))
-                return "no start script specified";
-
-	if(!getOption(line, &idx))
-		return "no number specified for dial";
-
-        return NULL;
-}
-	
-const char *Checks::chkStart(Line *line, ScriptImage *img)
-{
-	unsigned idx = 0;
-
-	if(!useKeywords(line, "=vars=session=timeout=duration"))
-		return "invalid keyword used for start";
-
-	if(!getOption(line, &idx))
-		return "no start script specified";
-
-	if(getOption(line, &idx))
-		return "only one script name used in start";
-
-	return NULL;
-}
-
 } // end namespace
