@@ -39,12 +39,18 @@ private:
         void detach(ScriptInterp *interp);
 	bool select(ScriptInterp *interp);
         bool reload(ScriptCompiler *img);
-	Name *service(ScriptImage *img, ScriptInterp *interp, const char *sid);
 	void down(void);
 
         void compileDir(const char *prefix, ScriptCompiler *img);
 
+	Name *getIncoming(ScriptImage *img, BayonneSession *s, Event *event);
+
 	static bool testKey(ScriptInterp *interp, const char *v);
+	static bool testRegistered(ScriptInterp *interp, const char *v);
+	static bool testExternal(ScriptInterp *interp, const char *v);
+	static bool testAvailable(ScriptInterp *interp, const char *v);
+	static bool testReachable(ScriptInterp *interp, const char *v);
+	static bool testDestination(ScriptInterp *interp, const char *v);
 
 public:
         Binder();
@@ -91,28 +97,47 @@ class Checks : public ScriptChecks, public Bayonne
 public:
         const char *chkCDR(Line *line, ScriptImage *img); 
         const char *chkRegister(Line *line, ScriptImage *img);
+		const char *chkKeydata(Line *line, ScriptImage *img);
         const char *chkAssign(Line *line, ScriptImage *img);
         const char *chkSelect(Line *line, ScriptImage *img);   
         const char *chkKey(Line *line, ScriptImage *img);  
-        const char *chkConnect(Line *line, ScriptImage *img); 
-        const char *chkStart(Line *line, ScriptImage *img); 
-	const char *chkCancel(Line *line, ScriptImage *img);
-        const char *chkJoin(Line *line, ScriptImage *img);
-        const char *chkWait(Line *line, ScriptImage *img); 
+	const char *chkConnect(Line *line, ScriptImage *img);
+	const char *chkStart(Line *line, ScriptImage *img);
+	const char *chkStop(Line *line, ScriptImage *img);
+	const char *chkJoin(Line *line, ScriptImage *img);
 	const char *chkDial(Line *line, ScriptImage *img);
+	const char *chkEndinput(Line *line, ScriptImage *img);
+	const char *chkReconnect(Line *line, ScriptImage *img);
+	const char *chkRecall(Line *line, ScriptImage *img);
+	const char *chkRing(Line *line, ScriptImage *img);
+	const char *chkFeature(Line *line, ScriptImage *img);
+	const char *chkRedial(Line *line, ScriptImage *img);
+	const char *chkErase(Line *line, ScriptImage *img);
+	const char *chkGreeting(Line *line, ScriptImage *img);
 };
 
 class Methods : public BayonneSession
 {
 public:
-	bool scrSignal(void);
+	void msgAudio(void);
+	bool scrKeydata(void);
 	bool scrKey(void);
-        bool scrStart(void); 
-	bool scrCancel(void);
-	bool scrDetach(void);
-        bool scrWait(void);   
-        bool scrJoin(void); 
+	bool scrRing(void);
+	bool scrRelease(void);
+	bool scrRecall(void);
+	bool scrConnect(void);
+	bool scrStart(void);
+	bool scrStop(void);
+	bool scrJoin(void);
 	bool scrDial(void);
+	bool scrForm(void);
+	bool scrEndform(void);
+	bool scrEndinput(void);
+	bool scrReconnect(void);
+	bool scrFeature(void);
+	bool scrRedial(void);
+	bool scrErase(void);
+	bool scrGreeting(void);
 };
 
 } // namespace
