@@ -249,6 +249,10 @@ BayonneRPC::BayonneRPC()
 {
 }
 
+BayonneRPC::~BayonneRPC()
+{
+}
+
 bool BayonneRPC::parseCall(char *cp)
 {
 	bool name_flag = false;
@@ -359,6 +363,35 @@ bool BayonneRPC::parseCall(char *cp)
 	return false;
 }
 
+void BayonneRPC::setComplete(BayonneSession *s)
+{
+	buildResponse("(sb)", 
+		"session", s->getSessionId(), 
+		"complete", (rpcbool_t)0);
+}
+
+const char *BayonneRPC::getParamId(unsigned short param, unsigned short offset)
+{
+    unsigned count = 0;
+    unsigned member = 1;
+
+    if(!offset)
+        offset = 1;
+
+	while(count < params.count)
+	{
+		if(params.param[count] > param)
+			break;
+
+		if(params.param[count] == param)
+			if(member++ == offset)
+				return (const char *)params.name[count];
+
+		++count;
+	}
+	return NULL;
+}
+
 const char *BayonneRPC::getIndexed(unsigned short param, unsigned short offset)
 {
 	unsigned count = 0;
