@@ -1570,7 +1570,6 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	InetAddress host;
 	bool ext = false, gw = false;
 	Image *ip = (Image *)img;
-	Keydata *cfg = NULL;
 	const char *gateways = NULL;
 
 	memset(reg, 0, sizeof(Registry));
@@ -1583,7 +1582,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(ext || gw)
 	{
 		if(!ScriptChecks::useKeywords(line, 
-			"=reconnect=peering=secret=encoding=framing=dtmf=user=count=device"
+			"=reconnect=peering=secret=encoding=framing=dtmf=user=count"
 			"=info=answer=accept=hold=transfer=update=group"))
 				return "invalid keywords used for sip external";
 	}
@@ -1614,6 +1613,22 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	reg->group = regKeyword(line, "group");
 	gateways = regKeyword(line, "gateways");
 
+	if(reg->type && (!strnicmp(reg->type, "rem", 3)
+		|| !stricmp(reg->type, "opx")))
+	{
+		ext = true;
+		reg->type = "ext";
+		if(!reg->reconnect)
+			reg->reconnect = getLast("remote.reconnect");
+		if(!reg->peering)
+			reg->peering = "no";
+		cp = getLast("remote.encoding");
+		if(cp && !reg->encoding && reg->reconnect && stristr(reg->reconnect, cp))
+			reg->encoding = cp;
+		if(!reg->encoding)
+			reg->encoding = getLast("message.encoding");
+	}
+
 	if(!stricmp(line->cmd, "_keydata_"))
 	{
 		if(reg->type && !strnicmp(reg->type, "ext", 3))
@@ -1630,7 +1645,23 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		reg->accept = atol(cp);
 
 	if(ext || gw)
+	{
+		if(!reg->reconnect && !reg->peering && !reg->encoding)
+			reg->reconnect = img->getLast("local.reconnect");
+		if(!reg->encoding && !reg->peering && reg->reconnect)
+		{
+			cp = img->getLast("local.encoding");
+			if(cp && stristr(reg->reconnect, cp))
+			{
+				reg->encoding = cp;
+				reg->peering = "yes";
+			}
+		}
+		if(!reg->encoding)
+			reg->encoding = img->getLast("message.encoding");
+			
 		reg->localid = regKeyword(line, "user");
+	}
 	if(gw && !reg->localid)
 		reg->localid = regKeyword(line, "userid");
 
@@ -1675,81 +1706,6 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		cp = "0";
 	reg->framing = atol(cp);
 	
-#ifndef	WIN32
-	cp = regKeyword(line, "device");
-	if(cp)
-	{
-		snprintf(buf, sizeof(buf), "/bayonne/device/%s", cp);
-		cfg = new Keydata(buf);
-	}
-
-	if(cfg)
-	{
-		cp = cfg->getLast("realm");
-		if(cp && !reg->realm)
-			reg->realm = ip->dupString(cp);
-		cp = cfg->getLast("type");
-		if(cp && !reg->type)
-			reg->type = cp;
-		cp = cfg->getLast("count");
-		if(cp && !reg->call_limit)
-			reg->call_limit = atoi(cp);
-			
-		cp = cfg->getLast("dtmf");
-		if(cp && !reg->dtmf)
-			reg->dtmf = ip->dupString(cp);					
-
-		cp = cfg->getLast("secret");
-		if(cp && !reg->secret)
-			reg->secret = ip->dupString(cp);
-
-		if(!insecure)
-			insecure = cfg->getLast("insecure");
-
-		cp = cfg->getLast("user");
-		if(cp && !reg->userid)
-			reg->userid = ip->dupString(cp);
-
-		cp = cfg->getLast("encodings");
-		if(cp && !strstr(cp, getLast("encoding")))
-			cp = cfg->getLast("preferred");
-		else
-			cp = NULL;
-		if(!cp)
-			cp = cfg->getLast("encoding");
-		if(cp && !reg->encoding)
-		{
-			reg->encoding = ip->dupString(cp);
-			cp = cfg->getLast("framing");
-			if(cp)
-				reg->framing = atol(cp);
-		}
-		cp = cfg->getLast("update");
-		if(cp && !reg->update)
-			reg->update = ip->dupString(cp);
-		cp = cfg->getLast("transfer");
-		if(cp && !reg->transfer)
-			reg->transfer = ip->dupString(cp);
-		cp = cfg->getLast("hold");
-		if(cp && !reg->hold)
-			reg->hold = ip->dupString(cp);
-		cp = cfg->getLast("accept");
-		if(cp && !reg->accept)
-			reg->accept = atoi(cp);
-		cp = cfg->getLast("answer");
-		if(cp && !reg->answer)
-			reg->answer = cp;
-		cp = cfg->getLast("reconnect");
-		if(cp && !reg->reconnect)
-			reg->reconnect = ip->dupString(cp);
-		cp = cfg->getLast("peering");
-		if(cp && !strnicmp(cp, "no", 2))
-			reg->peering = NULL;
-		else if(cp && !reg->peering)
-			reg->peering = ip->dupString(cp);
-		delete cfg;
-	}
-#endif
 	if(ext)
 	{
 		if(!reg->hold)
@@ -1882,7 +1838,6 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		reg->localid = (const char *)img->getMemory(len);
 		strcpy((char *)reg->localid, buf + 4);
 	}
-//** ADDED
 	else
 		setString(buf + 4, sizeof(buf) - 4, reg->localid);
 
