@@ -106,7 +106,8 @@ public:
 		P_ONLINE = P_AVAILABLE
 	} presence;
 	
-	char address[48];
+	char address[80];
+	char secret[16];
 };	
 
 class Registry : public ScriptRegistry
@@ -215,6 +216,9 @@ public:
 
 	Session *getCall(int callid);
 
+	bool deregister(const char *id);
+	bool reregister(const char *id, const char *uri, const char *secret, timeout_t expires);
+
 	void setAuthentication(Registry *reg, osip_message_t *response);
 	bool getAuthentication(Session *s, osip_message_t *response);
 	bool isExternal(const char *ext);
