@@ -45,6 +45,7 @@ void RTPStream::newSession(void)
 
         dropInbound = false;
         oTimestamp = 0;
+	pTimestamp = 0;
 	source = NULL;
 	sink = NULL;
 	tone = NULL;
@@ -112,6 +113,7 @@ void RTPStream::start(void)
 	setPayloadFormat(pf);	
 	setMaxSendSegmentSize(1024);
 
+	pTimestamp = 0;
 	source = NULL;
 	sink = NULL;
 	tonecount = 0;
@@ -415,6 +417,9 @@ void RTPStream::runActive(void)
 
         setTimer(0);
 
+	interval = info.framing;
+	interval *= (getCurrentRTPClockRate() / 1000);
+
 	setCancel(cancelDeferred);
         for(;;)
         {
@@ -549,6 +554,7 @@ void RTPStream::runActive(void)
 				silent = false;
 	                        putNative(buffer, size);
 			}
+
 			else if(!ending)
 			{
 				fcount = 0;
@@ -572,8 +578,8 @@ done:
 		leave();
 		if(silent && Driver::sip.data_filler)
 		{
-			silent = false;
 			putNative(silent_encoded, info.framesize);
+			silent = false;
 		}
 
 		r = dispatchDataPacket();
@@ -702,12 +708,30 @@ done:
 
 ssize_t RTPStream::putBuffer(Encoded data, size_t len)
 {
-        uint32 result = info.framing;
-        result *= (getCurrentRTPClockRate() / 1000);
         if(!oTimestamp)
-                oTimestamp = getCurrentTimestamp();
-//	printf("DRIFT %ld\n", (long)oTimestamp - (long)getCurrentTimestamp());
-        oTimestamp += result;
+	{
+                oTimestamp = (getCurrentTimestamp() / interval) * interval - interval;
+		if(pTimestamp && oTimestamp < pTimestamp)
+			oTimestamp = pTimestamp;
+		else if(pTimestamp && oTimestamp >= pTimestamp + interval && Driver::sip.data_filler)
+		{
+			unsigned add = ((oTimestamp - pTimestamp) / interval);
+			if(add > 10)
+				add = 1;
+			while(add--)
+			{
+				oTimestamp += interval;
+				if(Driver::sip.send_immediate)
+					sendImmediate(oTimestamp, silent_encoded, info.framesize);
+				else
+					putData(oTimestamp, silent_encoded, info.framesize);
+			}
+			slog.debug("%s: rtp underfill; packets added", session->logname);
+		}
+	}
+	// printf("DRIFT %ld\n", (long)oTimestamp - (long)getCurrentTimestamp());
+        oTimestamp += interval;
+	pTimestamp = oTimestamp;
 	if(Driver::sip.send_immediate)
 		sendImmediate(oTimestamp, (const unsigned char *)data, len);
 	else
@@ -717,11 +741,14 @@ ssize_t RTPStream::putBuffer(Encoded data, size_t len)
 
 void RTPStream::put2833(struct dtmf2833 *data)
 {
-	uint32 result = info.framing;
-        result *= (getCurrentRTPClockRate() / 1000);
         if(!oTimestamp)
+	{
                 oTimestamp = getCurrentTimestamp();
-        oTimestamp += result;
+		if(oTimestamp < pTimestamp)
+			oTimestamp = pTimestamp;
+	}
+        oTimestamp += interval;
+	pTimestamp = oTimestamp;
 	if(Driver::sip.send_immediate)
 		sendImmediate(oTimestamp, (const unsigned char *)data, 
 			sizeof(struct dtmf2833));
