@@ -47,8 +47,6 @@ private:
 
 	class EventStream *next, *prev;
 
-	unsigned char *tsmap;
-	unsigned char *spanmap;
 	char authorized[96];
 
 	void release(void);
@@ -57,6 +55,7 @@ public:
 	EventStream();
 	static EventStream *create(int so, const char *auth = NULL);
 	bool sendEvent(const char *msg);
+	void sendReply(const char *msg);
 	bool isConnected(void);
 };
 
@@ -115,6 +114,8 @@ protected:
 	void htmlCalls(void);
 	void htmlControl(void);
 
+	void setComplete(BayonneSession *s);
+
 	char *urlDecode(char *source);
 	char *b64Decode(char *source);
 
