@@ -613,6 +613,16 @@ events:
 	syncExit();
 }
 
+void Session::setComplete(BayonneSession *s)
+{
+	EventStream::create(so, s->getSessionId());
+	s->setConst("session.exit_manager", "webservice");
+	s->leave();
+	so = INVALID_SOCKET;
+	state = Socket::INITIAL;
+	syncExit();
+}
+
 void Session::postDocument(const char *file, unsigned long size)
 {
     char nbuf[256];
