@@ -54,14 +54,14 @@ void Session::rpcFault(int code, const char *string)
 void Session::rpcReply(const char *string)
 {
 	strcpy(buffer, "<?xml version=\"1.0\"?>\r\n");
-	strcat(buffer, "<methodResponse>\r\n");
+	strcat(buffer, "<methodResponse><params>\r\n");
 	if(string)
 	{
-		strcat(buffer, " <params><param><value>\r\n  <string>");
+		strcat(buffer, " <param><value>\r\n  <string>");
 		strcat(buffer, string);
-		strcat(buffer, "</string>\r\n </value></param></params>\r\n");
+		strcat(buffer, "</string>\r\n </value></param>\r\n");
 	}
-	strcat(buffer, "</methodResponse>\r\n");
+	strcat(buffer, "</params></methodResponse>\r\n");
 	sendHeader("text/xml", strlen(buffer));
 	sendText(buffer);
 	syncExit();
