@@ -52,6 +52,17 @@ using namespace std;
 #define	PHRASE_FILES	LIBDIR_FILES
 #endif
 
+static Keydata::Define keypad[] = {
+	{"2", "abc"},
+	{"3", "def"},
+	{"4", "ghi"},
+	{"5", "jkl"},
+	{"6", "mno"},
+	{"7", "pqrs"},
+	{"8", "tuv"},
+	{"9", "wxyz"},
+	{NULL, NULL}}; 
+
 static Keydata::Define paths[] = {
 	{"libexec", LIBEXEC_FILES},
 	{"datafiles", VAR_FILES},
@@ -100,6 +111,31 @@ static Keydata::Define libkeys[] = {
 	{"ttslimit", "0"},
 	{NULL, NULL}};
 
+static Keydata::Define localkeys[] = {
+	{"encoding", "ulaw"},
+	{"framing", "20"},
+	{"ringing", "20s"},
+	{"reconnect", "ulaw,alaw,g721,gsm"},
+	{NULL, NULL}};
+
+static Keydata::Define remotekeys[] = {
+    {"encoding", "gsm"},
+    {"framing", "20"},
+    {"ringing", "20s"},
+    {"reconnect", "ulaw,alaw,g721,gsm"},
+    {NULL, NULL}};
+
+static Keydata::Define msgkeys[] = {
+	{"extension", ".au"},
+	{"encoding", "ulaw"},
+	{"framing", "20"},
+	{"maxlimit", "600s"},
+	{"greeting", "60s"},
+	{"new", "7d"},
+	{"read", "4w"},
+	{"saved", "never"},
+    {NULL, NULL}};
+
 static Keydata::Define smtpkeys[] = {
 	{"limit", "0"},
 	{"sendmail", "/usr/sbin/sendmail"},
@@ -114,6 +150,16 @@ static Keydata::Define urlkeys[] = {
 	{"agent", "bayonne/" VERSION},
 	{NULL, NULL}};
 
+static class KeymapConfig : public ReconfigKeydata, public Bayonne
+{
+private:
+	virtual void updateConfig(Keydata *cfg);
+
+public:
+	KeymapConfig();
+
+}	keymap;
+
 bool flag_daemon = false;
 bool flag_check = false;
 
@@ -123,9 +169,59 @@ StaticKeydata keyengine("/bayonne/server/engine", engine);
 BayonneConfig keylibexec("libexec", libkeys, "/bayonne/server/libexec");
 BayonneConfig keysmtp("smtp", smtpkeys, "/bayonne/server/smtp");
 BayonneConfig keyurl("url", urlkeys, "/bayonne/server/url");
+BayonneConfig keymessage("message", msgkeys, "/bayonne/server/message");
+BayonneConfig keylocal("local", localkeys, "/bayonne/server/local");
+BayonneConfig keyremote("remote", remotekeys, "/bayonne/server/remote");
 
 Keydata keyoptions;
 
+KeymapConfig::KeymapConfig() :
+ReconfigKeydata("/bayonne/server/keymap", keypad)
+{
+	KeymapConfig::updateConfig(NULL);
+}
+
+void KeymapConfig::updateConfig(Keydata *cfg)
+{
+	char localmap[256];
+	char keycode[2];
+	unsigned char c, code;
+	const char *cp;
+
+	keycode[1] = 0;
+	memset(localmap, 0, sizeof(localmap));
+	for(c = '0'; c <= '9'; ++c)
+	{
+		code = (unsigned char)c;
+		localmap[code] = c;
+		keycode[0] = c;
+		cp = updatedString(keycode);
+		if(!cp || !*cp)
+			continue;
+		while(*cp)
+		{
+			if(isalpha(*cp))
+			{
+				code = (unsigned char)toupper(*cp);
+				localmap[code] = c;
+				code = (unsigned char)tolower(*cp);
+				localmap[code] = c;
+			}
+			else
+			{
+				code = (unsigned char)*cp;
+				localmap[code] = c;
+			}
+			++cp;
+		}
+	}
+	code = (unsigned char)'*';
+	localmap[code] = '*';
+	code = (unsigned char)'#';
+	localmap[code] = '#';
+	memcpy(dtmf_keymap, localmap, 256);
+}
+
 void liveConfig(void)
 {
 	const char *cfgid = Process::getEnv("CONFIG");
