@@ -170,19 +170,6 @@ static void loading(void)
        	Process::setEnv("SERVER_TOKEN", " ", true);
 
 #ifdef	HAVE_LIBEXEC
-	keyurl.setEnv("agent");
-	keyurl.setEnv("proxy");
-	keyurl.setEnv("local");
-	keyurl.setEnv("userid");
-	keyurl.setEnv("secret");
-	keyurl.setEnv("prefix");
-
-	keysmtp.setEnv("sendmail");
-	keysmtp.setEnv("errors");
-	keysmtp.setEnv("sender");
-	keysmtp.setEnv("userid");
-	keysmtp.setEnv("secret");
-
 	cp = Process::getEnv("LIBEXEC");
 	if(cp && !strnicmp(cp, "no", 2))
 		goto noexec;
@@ -362,13 +349,13 @@ start:
 	cp = keyserver.getLast("binding");
 #ifdef	WIN32
 	if(cp && !stricmp(cp, "default"))
-		cp = "ivrscript1";
+		cp = "ivrscript";
 #else
 	if(cp && !stricmp(cp, "default"))
 	{
 		cp = Process::getEnv("BINDING");
 		if(!cp || !*cp)
-			cp = "ivrscript1";
+			cp = "ivrscript";
 	}
 #endif
 	plugins();
@@ -415,7 +402,7 @@ static void checking(void)
 	if(!Bayonne::getTimeslotCount())
 		Bayonne::allocate(1, dynamic_cast<ScriptCommand *>(&runtime), 0);
 	if(cp && !stricmp(cp, "default"))
-		cp = "ivrscript1";
+		cp = "ivrscript";
 	plugins();
 	runtime.loadBinder(cp);
 	Bayonne::reload();
