@@ -64,6 +64,7 @@ ScriptThread(interp, 0), Dir(path)
 	sym = var;
 	prefix = interp->getKeyword("match");
 	suffix = interp->getKeyword("extension");
+	prior = interp->getKeyword("prior");
         after = interp->getKeyword("after");
         save = interp->getKeysymbol("after");
 
@@ -134,6 +135,9 @@ void ListThread::run(void)
 		}
 
 		note = NULL;
+				if(prior)
+					if(stricmp(name, prior) > 0)
+						continue;
 
                 if(after)
                         if(stricmp(name, after) <= 0)
@@ -149,9 +153,11 @@ void ListThread::run(void)
 		interp->enter();
 		if(note)
 		{
-			snprintf(buf, sizeof(buf), "%s,%s", name, note);
+			snprintf(buf, sizeof(buf), "id=%s;%s", name, note);
 			name = buf;
 		}
+		else if(longinfo)
+			snprintf(buf, sizeof(buf), "id=%s", name);
 	
 		interp->append(sym, name);
 		interp->leave();
